==> istio-model-v1alpha3-6.8.0-sources.jar: io/fabric8/istio/api/networking/v1alpha3/LoadBalancerSettingsConsistentHashLBHttpHeaderNameFluent.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class LoadBalancerSettingsConsistentHashLBHttpHeaderNameFluent<A extends LoadBalancerSettingsConsistentHashLBHttpHeaderNameFluent<A>> extends BaseFluent<A>{
  public LoadBalancerSettingsConsistentHashLBHttpHeaderNameFluent() {
  }
  public LoadBalancerSettingsConsistentHashLBHttpHeaderNameFluent(LoadBalancerSettingsConsistentHashLBHttpHeaderName instance) {
    instance = (instance != null ? instance : new LoadBalancerSettingsConsistentHashLBHttpHeaderName());

    if (instance != null) {
      this.withHttpHeaderName(instance.getHttpHeaderName());
      this.withHttpHeaderName(instance.getHttpHeaderName());
    }
  }
  private String httpHeaderName;
  public String getHttpHeaderName() {
    return this.httpHeaderName;
  }
  public A withHttpHeaderName(String httpHeaderName) {
    this.httpHeaderName=httpHeaderName; return (A) this;
  }
  public boolean hasHttpHeaderName() {
    return this.httpHeaderName != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    LoadBalancerSettingsConsistentHashLBHttpHeaderNameFluent that = (LoadBalancerSettingsConsistentHashLBHttpHeaderNameFluent) o;
    if (!java.util.Objects.equals(httpHeaderName, that.httpHeaderName)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(httpHeaderName,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (httpHeaderName != null) { sb.append("httpHeaderName:"); sb.append(httpHeaderName); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> istio-model-v1alpha3-6.9.0-sources.jar: io/fabric8/istio/api/networking/v1alpha3/LoadBalancerSettingsConsistentHashLBHttpHeaderNameFluent.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class LoadBalancerSettingsConsistentHashLBHttpHeaderNameFluent<A extends LoadBalancerSettingsConsistentHashLBHttpHeaderNameFluent<A>> extends BaseFluent<A>{
  public LoadBalancerSettingsConsistentHashLBHttpHeaderNameFluent() {
  }
  
  public LoadBalancerSettingsConsistentHashLBHttpHeaderNameFluent(LoadBalancerSettingsConsistentHashLBHttpHeaderName instance) {
    this.copyInstance(instance);
  }
  private String httpHeaderName;
  
  protected void copyInstance(LoadBalancerSettingsConsistentHashLBHttpHeaderName instance) {
    instance = (instance != null ? instance : new LoadBalancerSettingsConsistentHashLBHttpHeaderName());
  
    if (instance != null) {
        this.withHttpHeaderName(instance.getHttpHeaderName());
        this.withHttpHeaderName(instance.getHttpHeaderName());
      }
  }
  
  public String getHttpHeaderName() {
    return this.httpHeaderName;
  }
  
  public A withHttpHeaderName(String httpHeaderName) {
    this.httpHeaderName=httpHeaderName; return (A) this;
  }
  
  public boolean hasHttpHeaderName() {
    return this.httpHeaderName != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    LoadBalancerSettingsConsistentHashLBHttpHeaderNameFluent that = (LoadBalancerSettingsConsistentHashLBHttpHeaderNameFluent) o;
    if (!java.util.Objects.equals(httpHeaderName, that.httpHeaderName)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(httpHeaderName,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (httpHeaderName != null) { sb.append("httpHeaderName:"); sb.append(httpHeaderName); }
    sb.append("}");
    return sb.toString();
  }
  

}
